@@ -10,11 +10,11 @@ Usage::
     client: PrometheusServiceClient = boto3.client("amp")
     ```
 """
-import sys
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_amp.literals import ListWorkspacesPaginatorName
 from mypy_boto3_amp.paginator import ListWorkspacesPaginator
 from mypy_boto3_amp.type_defs import (
     CreateWorkspaceResponseTypeDef,
@@ -22,12 +22,6 @@ from mypy_boto3_amp.type_defs import (
     ListWorkspacesResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("PrometheusServiceClient",)
 
 
@@ -52,7 +46,7 @@ class Exceptions:
 
 class PrometheusServiceClient:
     """
-    [PrometheusService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client)
+    [PrometheusService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client)
     """
 
     meta: ClientMeta
@@ -60,24 +54,24 @@ class PrometheusServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.can_paginate)
         """
 
     def create_workspace(
         self, alias: str = None, clientToken: str = None
     ) -> CreateWorkspaceResponseTypeDef:
         """
-        [Client.create_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.create_workspace)
+        [Client.create_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.create_workspace)
         """
 
     def delete_workspace(self, workspaceId: str, clientToken: str = None) -> None:
         """
-        [Client.delete_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.delete_workspace)
+        [Client.delete_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.delete_workspace)
         """
 
     def describe_workspace(self, workspaceId: str) -> DescribeWorkspaceResponseTypeDef:
         """
-        [Client.describe_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.describe_workspace)
+        [Client.describe_workspace documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.describe_workspace)
         """
 
     def generate_presigned_url(
@@ -88,24 +82,24 @@ class PrometheusServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.generate_presigned_url)
         """
 
     def list_workspaces(
         self, alias: str = None, maxResults: int = None, nextToken: str = None
     ) -> ListWorkspacesResponseTypeDef:
         """
-        [Client.list_workspaces documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.list_workspaces)
+        [Client.list_workspaces documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.list_workspaces)
         """
 
     def update_workspace_alias(
         self, workspaceId: str, alias: str = None, clientToken: str = None
     ) -> None:
         """
-        [Client.update_workspace_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Client.update_workspace_alias)
+        [Client.update_workspace_alias documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Client.update_workspace_alias)
         """
 
-    def get_paginator(self, operation_name: Literal["list_workspaces"]) -> ListWorkspacesPaginator:
+    def get_paginator(self, operation_name: ListWorkspacesPaginatorName) -> ListWorkspacesPaginator:
         """
-        [Paginator.ListWorkspaces documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.42/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
+        [Paginator.ListWorkspaces documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/amp.html#PrometheusService.Paginator.ListWorkspaces)
         """
