@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_amp.literals import WorkspaceStatusCode
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -48,10 +46,7 @@ class WorkspaceDescriptionTypeDef(
     pass
 
 
-WorkspaceStatusTypeDef = TypedDict(
-    "WorkspaceStatusTypeDef",
-    {"statusCode": Literal["CREATING", "ACTIVE", "UPDATING", "DELETING", "CREATION_FAILED"]},
-)
+WorkspaceStatusTypeDef = TypedDict("WorkspaceStatusTypeDef", {"statusCode": WorkspaceStatusCode})
 
 _RequiredWorkspaceSummaryTypeDef = TypedDict(
     "_RequiredWorkspaceSummaryTypeDef",
